"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWidgetDataUrl = getWidgetDataUrl;
exports.getLegacyWidgetDomain = getLegacyWidgetDomain;
exports.embed = embed;
const constants_1 = require("../constants");
const v2_1 = require("./v2");
const v3_1 = require("./v3");
function getWidgetDataUrl(env) {
    switch (env) {
        case "staging":
            return constants_1.STAGING_DATA_URL;
        default:
            return constants_1.PRODUCTION_DATA_URL;
    }
}
function getLegacyWidgetDomain(env) {
    switch (env) {
        case "staging":
            return constants_1.STAGING_LEGACY_WIDGET_DOMAIN;
        default:
            return constants_1.PRODUCTION_LEGACY_WIDGET_DOMAIN;
    }
}
function getRequestUrl(widgetId, environment) {
    return `${getWidgetDataUrl(environment)}/widgets/${widgetId}/version`;
}
async function retrieveWidgetVersionFromServer(widgetId, environment) {
    const response = await fetch(getRequestUrl(widgetId, environment));
    const json = await response.json();
    return json.version;
}
function injectHTML(root, html) {
    root.appendChild(document.createRange().createContextualFragment(html));
}
async function embed(options) {
    const { environment, widgetId, root, version, dataProperties } = options;
    try {
        const widgetVersion = version ?? (await retrieveWidgetVersionFromServer(widgetId, environment));
        switch (widgetVersion) {
            case 2:
                window.stackWidgetDomain = getLegacyWidgetDomain(environment);
                dataProperties.hash = widgetId;
                injectHTML(root, (0, v2_1.getWidgetV2EmbedCode)(dataProperties));
                (0, v2_1.invokeV2Javascript)(environment);
                break;
            case 3:
                dataProperties.wid = widgetId;
                injectHTML(root, (0, v3_1.getWidgetV3EmbedCode)(dataProperties));
                await (0, v3_1.invokeV3Javascript)(environment);
                break;
            default:
                throw new Error(`No widget code accessible with version ${widgetVersion}`);
        }
    }
    catch (error) {
        console.error(`Failed to embed widget. ${error}`);
    }
}
//# sourceMappingURL=index.js.map