"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars_1 = __importDefault(require("handlebars"));
const if_has_product_tags_helper_1 = require("./if-has-product-tags.helper");
describe("hasProductTagsHelper", () => {
    beforeAll(() => {
        (0, if_has_product_tags_helper_1.loadIfHasProductTags)(handlebars_1.default);
    });
    it("should render the product tags item because product tags exist", () => {
        const template = handlebars_1.default.compile(`
      {{#ifHasProductTags tile}}
        Display
      {{else}}
        Not Display
      {{/ifHasProductTags}}
    `);
        const result = template({
            tile: {
                tags_extended: [
                    {
                        type: "product"
                    }
                ]
            }
        });
        expect(result.trim()).toBe("Display");
    });
    it("should not render the product tags item because product tags do not exist", () => {
        const template = handlebars_1.default.compile(`
      {{#ifHasProductTags tile}}
        Display
      {{else}}
        Not Display
      {{/ifHasProductTags}}
    `);
        const result = template({
            tile: {
                tags_extended: []
            }
        });
        expect(result.trim()).toBe("Not Display");
    });
    it("should not render because all tags are system tags", () => {
        const template = handlebars_1.default.compile(`
      {{#ifHasProductTags tile}}
        Display
      {{else}}
        Not Display
      {{/ifHasProductTags}}
    `);
        const result = template({
            tile: {
                tags_extended: [
                    {
                        type: "system"
                    }
                ]
            }
        });
        expect(result.trim()).toBe("Not Display");
    });
});
//# sourceMappingURL=if-has-product-tags.helper.spec.js.map