"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars_1 = __importDefault(require("handlebars"));
const if_short_video_helper_1 = require("./if-short-video.helper");
describe("loadIfShortVideoHelper", () => {
    beforeAll(() => {
        (0, if_short_video_helper_1.loadIfShortVideoHelper)(handlebars_1.default);
    });
    it("should render the Display block if the media is instagram reel", () => {
        const template = handlebars_1.default.compile(`
      {{#ifShortVideo tile}}
        Display
      {{else}}
        Not Display
      {{/ifShortVideo}}
    `);
        const result = template({
            tile: {
                source: "instagram",
                attrs: ["src:graph", "instagram.reel"],
                media: "video"
            }
        });
        expect(result.trim()).toBe("Display");
    });
    it("should render the Display block if the media is youtube short", () => {
        const template = handlebars_1.default.compile(`
      {{#ifShortVideo tile}}
        Display
      {{else}}
        Not Display
      {{/ifShortVideo}}
    `);
        const result = template({
            tile: {
                source: "youtube",
                attrs: ["src:graph", "youtube.short"],
                media: "video"
            }
        });
        expect(result.trim()).toBe("Display");
    });
    it("should render the Display block if the media is tiktok short", () => {
        const template = handlebars_1.default.compile(`
      {{#ifShortVideo tile}}
        Display
      {{else}}
        Not Display
      {{/ifShortVideo}}
    `);
        const result = template({
            tile: {
                source: "tiktok",
                attrs: ["src:graph", "tiktok.short"],
                media: "video"
            }
        });
        expect(result.trim()).toBe("Display");
    });
    it("should render the Not Display block if the media is not youtube short", () => {
        const template = handlebars_1.default.compile(`
      {{#ifShortVideo tile}}
        Display
      {{else}}
        Not Display
      {{/ifShortVideo}}
    `);
        const result = template({
            tile: {
                source: "youtube",
                attrs: ["src:graph"],
                media: "video"
            }
        });
        expect(result.trim()).toBe("Not Display");
    });
    it("should render the Not Display block if the media is other platforms", () => {
        const template = handlebars_1.default.compile(`
      {{#ifShortVideo tile}}
        Display
      {{else}}
        Not Display
      {{/ifShortVideo}}
    `);
        const result = template({
            tile: {
                source: "Pinterest",
                attrs: ["src:graph", "tiktok.short"],
                media: "video"
            }
        });
        expect(result.trim()).toBe("Not Display");
    });
});
//# sourceMappingURL=if-short-video.helper.spec.js.map