"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars_1 = __importDefault(require("handlebars"));
const load_icons_helper_1 = require("./load-icons.helper");
describe("loadIconsHelper", () => {
    beforeAll(() => {
        (0, load_icons_helper_1.loadIconsHelper)(handlebars_1.default);
    });
    it("should generate HTML with Instagram reel icon and product tags", () => {
        const tile = {
            id: "123",
            attrs: ["instagram.reel"],
            tags_extended: [{ type: "product" }],
            media: "image",
            source: "instagram"
        };
        const template = handlebars_1.default.compile(`{{loadIcons tile}}`);
        const result = template({ tile });
        expect(result).toContain('<div class="content-icon icon-reel"></div>');
        expect(result).toContain('<div class="shopping-icon icon-products"></div>');
        expect(result).toContain('<div class="network-icon icon-instagram"></div>');
    });
    it("should generate HTML with video play icon", () => {
        const tile = {
            id: "456",
            attrs: [],
            tags_extended: [],
            media: "video",
            source: "youtube"
        };
        const template = handlebars_1.default.compile(`{{loadIcons tile}}`);
        const result = template({ tile });
        expect(result).toContain('<div class="icon-play"></div>');
        expect(result).toContain('<div class="network-icon icon-youtube"></div>');
    });
    it("should generate HTML without Instagram reel or product tags", () => {
        const tile = {
            id: "789",
            attrs: [],
            tags_extended: [],
            media: "image",
            source: "twitter"
        };
        const template = handlebars_1.default.compile(`{{loadIcons tile}}`);
        const result = template({ tile });
        expect(result).not.toContain('<div class="content-icon icon-reel"></div>');
        expect(result).not.toContain('<div class="shopping-icon icon-products"></div>');
        expect(result).toContain('<div class="network-icon icon-twitter"></div>');
    });
});
//# sourceMappingURL=load-icons.helper.spec.js.map