"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderHTMLWithTemplates = renderHTMLWithTemplates;
exports.renderTilesWithTemplate = renderTilesWithTemplate;
exports.renderTemplateWithPartials = renderTemplateWithPartials;
exports.loadHelpers = loadHelpers;
const handlebars_1 = __importDefault(require("handlebars"));
const helpers_1 = require("./helpers");
const tile_helper_1 = require("./helpers/tile.helper");
const if_auto_play_video_helper_1 = require("./helpers/if-auto-play-video.helper");
const play_video_helper_1 = require("./helpers/play-video.helper");
const if_short_video_helper_1 = require("./helpers/if-short-video.helper");
const if_has_product_tags_helper_1 = require("./helpers/if-has-product-tags.helper");
const if_has_public_tags_helper_1 = require("./helpers/if-has-public-tags.helper");
const load_icons_helper_1 = require("./helpers/load-icons.helper");
async function renderHTMLWithTemplates(tileTemplate, layoutTemplate, tiles, options) {
    loadHelpers(handlebars_1.default);
    const hbs = await renderTemplateWithPartials(handlebars_1.default.create(), {
        name: "tpl-tile",
        template: tileTemplate
    });
    const handlebarsTemplate = hbs.compile(layoutTemplate);
    return handlebarsTemplate({
        tiles,
        options
    });
}
async function renderTilesWithTemplate(tileTemplate, tiles, options) {
    loadHelpers(handlebars_1.default);
    const hbs = await renderTemplateWithPartials(handlebars_1.default.create(), {
        name: "tpl-tile",
        template: tileTemplate
    });
    const handlebarsTemplate = hbs.compile(tileTemplate);
    return tiles.map(tile => handlebarsTemplate({
        ...tile,
        options
    }));
}
function renderTemplateWithPartials(hbs, partial) {
    loadHelpers(hbs);
    hbs.registerPartial(partial.name, partial.template);
    return hbs;
}
function loadHelpers(hbs) {
    (0, helpers_1.loadIfEqualsHelper)(hbs);
    (0, helpers_1.loadLazyHelper)(hbs);
    (0, helpers_1.loadJoinHelper)(hbs);
    (0, tile_helper_1.loadTileHelper)(hbs);
    (0, if_auto_play_video_helper_1.loadIfAutoPlayVideoHelper)(hbs);
    (0, play_video_helper_1.loadPlayVideoHelper)(hbs);
    (0, if_short_video_helper_1.loadIfShortVideoHelper)(hbs);
    (0, if_has_product_tags_helper_1.loadIfHasProductTags)(hbs);
    (0, if_has_public_tags_helper_1.loadIfHasPublicTags)(hbs);
    (0, load_icons_helper_1.loadIconsHelper)(hbs);
}
//# sourceMappingURL=index.js.map