import { type Swiper } from "swiper";
import { LookupAttr } from "../../extensions/swiper/swiper.extension";
import { ISdk } from "../../../types";
type YoutubeContentWindow = Window & {
    play: () => void;
    pause: () => void;
    reset: () => void;
    mute: () => void;
    unMute: () => void;
};
export type YoutubeIframeElementType = HTMLIFrameElement & {
    contentWindow: YoutubeContentWindow;
};
type SwiperVideoElementType = Window | YoutubeContentWindow | HTMLVideoElement;
type VideoSource = "video" | "youtube" | "tiktok";
type SwiperVideoElementData = {
    element: SwiperVideoElementType;
    source: VideoSource;
};
/**
 * Play the video/audio attached to the slide on load where the element is a media element (video/youtube/tiktok)
 */
export declare function playMediaOnLoad(sdk: ISdk): Promise<void>;
/**
 * Play/Pause the video/audio attached to the slide on navigation where the element is a media element (video/youtube/tiktok)
 * @param { Swiper } swiper - the swiper element
 */
export declare function controlVideoPlayback(sdk: ISdk, swiper: Swiper): Promise<void>;
/**
 * Trigger media play for different media element sources ("video", "youtube", "tiktok")
 *
 * @param elementData - the media container element and the source
 * @param elementData.element - the container element of the media (video tag or iframe.contentWindow)
 * @param elementData.source - the media source (video for custom video source, youtube/tiktok)
 */
export declare function triggerPlay(sdk: ISdk, elementData?: SwiperVideoElementData): void;
/**
 * Trigger media pause for different element sources ("video", "youtube", "tiktok")
 *
 * @param elementData - the media container element and the source
 * @param elementData.element - the container element of the media (video tag or iframe.contentWindow)
 * @param elementData.source - the media source (video for custom video source, youtube/tiktok)
 */
export declare function triggerPause(elementData?: SwiperVideoElementData): void;
/**
 * Get swiper video/audio element at the provided index.
 *
 * @param { Swiper } swiper - the swiper element
 * @param { number } index - index of the slide to be returned
 * @param { number } isStory - if it is story widget
 * @returns the video/iframe element or undefined if the element at index is not a video/audio
 */
export declare function getSwiperVideoElement(sdk: ISdk, swiper: Swiper, index: number, isStory?: boolean): SwiperVideoElementData | undefined;
/**
 * Setup onload and onerror (yt-video-error) events for youtube media
 *
 * @param { Element } tile - the tile element
 * @param { HTMLElement } widgetSelector - the container of swiper element
 */
export declare function setupYoutubeEvents(sdk: ISdk, tile: Element, widgetSelector: HTMLElement): void;
/**
 * Setup tiktok player events using window.postMessage api
 * All media are paused by defult and only the media in the active slide is played
 */
export declare function setupTikTokPlayerReadyEvent(sdk: ISdk): void;
/**
 * Play media associated with currently active tile
 *
 * @param { Element } tile - tile element to check
 * @param { HTMLElement } widgetSelector - the container of the swiper element
 * @param { LookupAttr } lookupAttr - additional attribute lookup options for finding the first slide to load
 * @param { LookupAttr.name } lookupAttr.name - name of the attribute for e.g. data-yt-id or data-tiktok-id
 * @param { LookupAttr.value } lookupAttr.value - required value of the attribute
 */
export declare function playActiveMediaTileOnLoad(sdk: ISdk, tile: Element, widgetSelector: HTMLElement, lookupAttr?: LookupAttr): void;
/**
 * Setup onload and onerror events for custom video source
 *
 * @param { Element } tile - the tile element
 * @param { HTMLElement } widgetSelector - the container of swiper element
 */
export declare function setupVideoEvents(sdk: ISdk, tile: Element, widgetSelector: HTMLElement): void;
export {};
//# sourceMappingURL=expanded-tile-video.d.ts.map