"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.playTiktokVideo = playTiktokVideo;
exports.pauseTiktokVideo = pauseTiktokVideo;
exports.muteTiktokVideo = muteTiktokVideo;
exports.unMuteTiktokVideo = unMuteTiktokVideo;
exports.postTiktokMessage = postTiktokMessage;
/**
 * Post tiktok messages to play a video/audio
 *
 * @param { Window } frameWindow - tiktok frame contentWindow
 */
function playTiktokVideo(frameWindow) {
    postTiktokMessage(frameWindow, "unMute");
    postTiktokMessage(frameWindow, "play");
}
/**
 * Post tiktok messages to pause a video/audio and reset the current video progress
 *
 * @param { Window } frameWindow - tiktok frame contentWindow
 */
function pauseTiktokVideo(frameWindow) {
    postTiktokMessage(frameWindow, "mute");
    postTiktokMessage(frameWindow, "pause");
    postTiktokMessage(frameWindow, "seekTo", 0);
}
function muteTiktokVideo(frameWindow) {
    postTiktokMessage(frameWindow, "mute");
}
function unMuteTiktokVideo(frameWindow) {
    postTiktokMessage(frameWindow, "unMute");
}
/**
 *
 * @param { Window } frameWindow - tiktok frame contentWindow
 * @param { TiktokMessageType } type - message type to be posted ("play" | "pause" | "mute" | "unMute" | "seekTo")
 * @param { number } value - position of media progress. 0 to reset progress
 */
function postTiktokMessage(frameWindow, type, value) {
    frameWindow.postMessage({ type, value, "x-tiktok-player": true }, "https://www.tiktok.com");
    // Fallback logic to handle when TikTok player is not ready yet
    window.addEventListener("message", event => {
        if (event.data.type === "onPlayerReady" && event.data["x-tiktok-player"]) {
            frameWindow.postMessage({ type, value, "x-tiktok-player": true }, "https://www.tiktok.com");
        }
    });
}
//# sourceMappingURL=tiktok-message.js.map