"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentWrapper = ContentWrapper;
exports.ExpandedTile = ExpandedTile;
exports.IconSection = IconSection;
exports.ShopSpotTemplate = ShopSpotTemplate;
exports.ImageTemplate = ImageTemplate;
const __1 = require("../../");
const video_templates_1 = require("./video.templates");
function ContentWrapper({ sdk, id }) {
    const { show_shopspots } = sdk.getExpandedTileConfig();
    const tile = sdk.getTileById(id);
    if (!tile) {
        console.warn("Tile not found in ContentWrapper", id);
        return (0, __1.createElement)(__1.createFragment, null);
    }
    const shopspotEnabled = sdk.isComponentLoaded("shopspots") && show_shopspots && !!tile?.hotspots?.length;
    switch (tile.media) {
        case "video":
            return ((0, __1.createElement)(__1.createFragment, null,
                (0, __1.createElement)(video_templates_1.VideoContainer, { sdk: sdk, shopspotEnabled: shopspotEnabled, tile: tile }),
                (0, __1.createElement)(video_templates_1.VideoErrorFallbackTemplate, { sdk: sdk, tile: tile })));
        case "image":
            return (0, __1.createElement)(ImageTemplate, { sdk: sdk, tile: tile, image: tile.image, shopspotEnabled: shopspotEnabled });
        case "text":
            return (0, __1.createElement)("span", { class: "content-text" }, tile.message);
        case "html":
            return (0, __1.createElement)("span", { class: "content-html" }, tile.html);
        default:
            return (0, __1.createElement)(__1.createFragment, null);
    }
}
function ExpandedTile({ tile, sdk }) {
    const { show_products, show_tags, show_sharing, show_caption, show_timestamp, show_carousel_grouping } = sdk.getExpandedTileConfig();
    const tileHasCarouselItems = tile.instagram_media_type === "CAROUSEL_ALBUM";
    const carouselGroupingEnabled = sdk.isComponentLoaded("carousel-grouping") && show_carousel_grouping && tileHasCarouselItems;
    const productsEnabled = sdk.isComponentLoaded("products") && show_products && !!tile.tags_extended?.length;
    const tagsEnabled = show_tags;
    const sharingToolsEnabled = show_sharing;
    return ((0, __1.createElement)(__1.createFragment, null,
        (0, __1.createElement)("div", { class: "panel" },
            (0, __1.createElement)("div", { class: "panel-left" },
                (0, __1.createElement)(IconSection, { tile: tile, productsEnabled: productsEnabled }),
                (0, __1.createElement)("div", { class: "image-wrapper" },
                    (0, __1.createElement)("div", { class: "image-wrapper-inner" }, carouselGroupingEnabled && tile.carousel_children && tile.carousel_children.length > 1 ? ((0, __1.createElement)("carousel-grouping", { "tile-id": tile.id, mode: "expanded" })) : ((0, __1.createElement)(ContentWrapper, { sdk: sdk, id: tile.id }))))),
            (0, __1.createElement)("div", { class: "panel-right" },
                (0, __1.createElement)("div", { class: "panel-right-wrapper" },
                    (0, __1.createElement)("div", { class: "content-wrapper" },
                        (0, __1.createElement)("div", { class: "content-inner-wrapper" },
                            (0, __1.createElement)("tile-content", { widgetId: sdk.getWidgetId(), tileId: tile.id, "render-share-menu": sharingToolsEnabled, "render-caption": show_caption, "render-timephrase": show_timestamp }),
                            tagsEnabled && ((0, __1.createElement)("tile-tags", { widgetId: sdk.getWidgetId(), "tile-id": tile.id, mode: "swiper", context: "expanded", "navigation-arrows": "true" })),
                            productsEnabled && ((0, __1.createElement)(__1.createFragment, null,
                                (0, __1.createElement)("ugc-products", { widgetId: sdk.getWidgetId(), "tile-id": tile.id }))))))))));
}
function IconSection({ tile, productsEnabled }) {
    const topSectionIconContent = [];
    const bottomSectionIconContent = [];
    if (tile.attrs?.includes("instagram.reel")) {
        topSectionIconContent.push((0, __1.createElement)("div", { class: "content-icon icon-reel" }));
    }
    else if (tile.attrs?.includes("youtube.short")) {
        topSectionIconContent.push((0, __1.createElement)("div", { class: "content-icon icon-youtube-short" }));
    }
    if (productsEnabled &&
        tile.tags_extended &&
        tile.tags_extended.length &&
        tile.tags_extended.find(tag => tag.type == "product")) {
        topSectionIconContent.push((0, __1.createElement)("div", { class: "shopping-icon icon-products" }));
    }
    bottomSectionIconContent.push((0, __1.createElement)("div", { class: `network-icon icon-${tile.source}` }));
    return ((0, __1.createElement)("div", { class: "icon-section" },
        (0, __1.createElement)("div", { class: "top-section" }, ...topSectionIconContent),
        (0, __1.createElement)("div", { class: "bottom-section" }, ...bottomSectionIconContent)));
}
function ShopSpotTemplate({ shopspotEnabled, tileId, sdk }) {
    return shopspotEnabled ? ((0, __1.createElement)(__1.createFragment, null,
        (0, __1.createElement)("shopspot-icon", { widgetId: sdk.getWidgetId(), mode: "expanded", "tile-id": tileId }))) : ((0, __1.createElement)(__1.createFragment, null));
}
function ImageTemplate({ tile, image, shopspotEnabled = false, sdk }) {
    return image ? ((0, __1.createElement)(__1.createFragment, null,
        (0, __1.createElement)("a", { href: tile.original_url, target: "_blank" },
            (0, __1.createElement)("div", { class: "image-filler blurred", style: { "background-image": `url('${image}')` } })),
        (0, __1.createElement)("div", { class: "image" },
            shopspotEnabled ? (0, __1.createElement)(ShopSpotTemplate, { sdk: sdk, shopspotEnabled: shopspotEnabled, tileId: tile.id }) : (0, __1.createElement)(__1.createFragment, null),
            (0, __1.createElement)("a", { href: tile.original_url, target: "_blank" },
                (0, __1.createElement)("img", { class: "image-element", src: image, loading: "lazy", alt: tile.description || "Image" }))))) : ((0, __1.createElement)(__1.createFragment, null));
}
//# sourceMappingURL=tile.template.js.map