import { STAGING_DATA_URL, PRODUCTION_DATA_URL, STAGING_LEGACY_WIDGET_DOMAIN, PRODUCTION_LEGACY_WIDGET_DOMAIN } from "../constants";
import { getWidgetV2EmbedCode, invokeV2Javascript } from "./v2";
import { getWidgetV3EmbedCode, invokeV3Javascript } from "./v3";
export function getWidgetDataUrl(env) {
    switch (env) {
        case "staging":
            return STAGING_DATA_URL;
        default:
            return PRODUCTION_DATA_URL;
    }
}
export function getLegacyWidgetDomain(env) {
    switch (env) {
        case "staging":
            return STAGING_LEGACY_WIDGET_DOMAIN;
        default:
            return PRODUCTION_LEGACY_WIDGET_DOMAIN;
    }
}
function getRequestUrl(widgetId, environment) {
    return `${getWidgetDataUrl(environment)}/widgets/${widgetId}/version`;
}
async function retrieveWidgetVersionFromServer(widgetId, environment) {
    const response = await fetch(getRequestUrl(widgetId, environment));
    const json = await response.json();
    return json.version;
}
function injectHTML(root, html) {
    root.appendChild(document.createRange().createContextualFragment(html));
}
export async function embed(options) {
    const { environment, widgetId, root, version, dataProperties } = options;
    try {
        const widgetVersion = version ?? (await retrieveWidgetVersionFromServer(widgetId, environment));
        switch (widgetVersion) {
            case 2:
                window.stackWidgetDomain = getLegacyWidgetDomain(environment);
                dataProperties.hash = widgetId;
                injectHTML(root, getWidgetV2EmbedCode(dataProperties));
                invokeV2Javascript(environment);
                break;
            case 3:
                dataProperties.wid = widgetId;
                injectHTML(root, getWidgetV3EmbedCode(dataProperties));
                await invokeV3Javascript(environment);
                break;
            default:
                throw new Error(`No widget code accessible with version ${widgetVersion}`);
        }
    }
    catch (error) {
        console.error(`Failed to embed widget. ${error}`);
    }
}
//# sourceMappingURL=index.js.map