import Handlebars from "handlebars";
import { loadIfEqualsHelper, loadJoinHelper, loadLazyHelper } from "./helpers";
import { loadTileHelper } from "./helpers/tile.helper";
import { loadIfAutoPlayVideoHelper } from "./helpers/if-auto-play-video.helper";
import { loadPlayVideoHelper } from "./helpers/play-video.helper";
import { loadIfShortVideoHelper } from "./helpers/if-short-video.helper";
import { loadIfHasProductTags } from "./helpers/if-has-product-tags.helper";
import { loadIfHasPublicTags } from "./helpers/if-has-public-tags.helper";
import { loadIconsHelper } from "./helpers/load-icons.helper";
export async function renderHTMLWithTemplates(tileTemplate, layoutTemplate, tiles, options) {
    loadHelpers(Handlebars);
    const hbs = await renderTemplateWithPartials(Handlebars.create(), {
        name: "tpl-tile",
        template: tileTemplate
    });
    const handlebarsTemplate = hbs.compile(layoutTemplate);
    return handlebarsTemplate({
        tiles,
        options
    });
}
export async function renderTilesWithTemplate(tileTemplate, tiles, options) {
    loadHelpers(Handlebars);
    const hbs = await renderTemplateWithPartials(Handlebars.create(), {
        name: "tpl-tile",
        template: tileTemplate
    });
    const handlebarsTemplate = hbs.compile(tileTemplate);
    return tiles.map(tile => handlebarsTemplate({
        ...tile,
        options
    }));
}
export function renderTemplateWithPartials(hbs, partial) {
    loadHelpers(hbs);
    hbs.registerPartial(partial.name, partial.template);
    return hbs;
}
export function loadHelpers(hbs) {
    loadIfEqualsHelper(hbs);
    loadLazyHelper(hbs);
    loadJoinHelper(hbs);
    loadTileHelper(hbs);
    loadIfAutoPlayVideoHelper(hbs);
    loadPlayVideoHelper(hbs);
    loadIfShortVideoHelper(hbs);
    loadIfHasProductTags(hbs);
    loadIfHasPublicTags(hbs);
    loadIconsHelper(hbs);
}
//# sourceMappingURL=index.js.map