import { createElement } from "../../";
export function EmbedYoutube({ tileId, videoId, onLoad }) {
    const contentElement = loadYoutubeIframeContent(tileId, videoId);
    return (createElement("iframe", { loading: "lazy", id: `yt-frame-${tileId}-${videoId}`, tileid: tileId, class: "video-content", height: "360px", width: "480px", frameborder: "0", enablejsapi: "1", onload: onLoad, srcdoc: contentElement.innerHTML }));
}
function loadYoutubeIframeContent(tileId, videoId) {
    const scriptId = `yt-script-${tileId}-${videoId}`;
    const playerId = `yt-player-${tileId}-${videoId}`;
    return (createElement("html", null,
        createElement("head", null,
            createElement("script", { id: scriptId, src: "https://www.youtube.com/iframe_api" }),
            createElement("script", null, loadYoutubePlayerAPI(playerId, videoId)),
            createElement("style", null, `
          body {
            margin: 0;
          }
        `)),
        createElement("body", null,
            createElement("div", { id: playerId }))));
}
export function loadYoutubePlayerAPI(playerId, videoId) {
    return `
  let player

  function loadPlayer(playDefault = false) {
    player = new YT.Player("${playerId}", {
      width: "100%",
      videoId: "${videoId}",
      playerVars: {
        playsinline: 1
      },
      events: {
        onReady: playDefault ? play : pause,
        onError: errorHandler
      }
    })
  }

  // API runs automatically once the iframe-api JS is downloaded.
  // This will not run when re-opening expanded tile
  function onYouTubeIframeAPIReady() {
    loadPlayer()
  }

  function errorHandler(e) {
   player?.getIframe().dispatchEvent(new CustomEvent("yt-video-error", { detail: e }))
  }

  function pause() {
    if (!player) {
      loadPlayer(false) //needed when expanded tile re-opened
    } else {
      if (!player || !player.mute) {
        setTimeout(() => {
          pause()
        }, 500)

        return
      }

      player.mute()
      player.pauseVideo()
    }
  }

  function destroy() {
    player?.destroy()
  }

  function reset() {
    player?.seekTo(0, false)
  }
  
   function mute() {
    player?.mute()
  }

  function unMute() {
    player?.unMute()
  }

  function play() {
    if (!player) {
      loadPlayer(true) //needed when expanded tile re-opened
    } else {
      if (player.isMuted()) {
        player.unMute()
      }
      player.playVideo()
    }
  } `;
}
//# sourceMappingURL=embed-youtube.template.js.map