import { createElement, createFragment } from "../../";
import { VideoContainer, VideoErrorFallbackTemplate } from "./video.templates";
export function ContentWrapper({ sdk, id }) {
    const { show_shopspots } = sdk.getExpandedTileConfig();
    const tile = sdk.getTileById(id);
    if (!tile) {
        console.warn("Tile not found in ContentWrapper", id);
        return createElement(createFragment, null);
    }
    const shopspotEnabled = sdk.isComponentLoaded("shopspots") && show_shopspots && !!tile?.hotspots?.length;
    switch (tile.media) {
        case "video":
            return (createElement(createFragment, null,
                createElement(VideoContainer, { sdk: sdk, shopspotEnabled: shopspotEnabled, tile: tile }),
                createElement(VideoErrorFallbackTemplate, { sdk: sdk, tile: tile })));
        case "image":
            return createElement(ImageTemplate, { sdk: sdk, tile: tile, image: tile.image, shopspotEnabled: shopspotEnabled });
        case "text":
            return createElement("span", { class: "content-text" }, tile.message);
        case "html":
            return createElement("span", { class: "content-html" }, tile.html);
        default:
            return createElement(createFragment, null);
    }
}
export function ExpandedTile({ tile, sdk }) {
    const { show_products, show_tags, show_sharing, show_caption, show_timestamp, show_carousel_grouping } = sdk.getExpandedTileConfig();
    const tileHasCarouselItems = tile.instagram_media_type === "CAROUSEL_ALBUM";
    const carouselGroupingEnabled = sdk.isComponentLoaded("carousel-grouping") && show_carousel_grouping && tileHasCarouselItems;
    const productsEnabled = sdk.isComponentLoaded("products") && show_products && !!tile.tags_extended?.length;
    const tagsEnabled = show_tags;
    const sharingToolsEnabled = show_sharing;
    return (createElement(createFragment, null,
        createElement("div", { class: "panel" },
            createElement("div", { class: "panel-left" },
                createElement(IconSection, { tile: tile, productsEnabled: productsEnabled }),
                createElement("div", { class: "image-wrapper" },
                    createElement("div", { class: "image-wrapper-inner" }, carouselGroupingEnabled && tile.carousel_children && tile.carousel_children.length > 1 ? (createElement("carousel-grouping", { "tile-id": tile.id, mode: "expanded" })) : (createElement(ContentWrapper, { sdk: sdk, id: tile.id }))))),
            createElement("div", { class: "panel-right" },
                createElement("div", { class: "panel-right-wrapper" },
                    createElement("div", { class: "content-wrapper" },
                        createElement("div", { class: "content-inner-wrapper" },
                            createElement("tile-content", { widgetId: sdk.getWidgetId(), tileId: tile.id, "render-share-menu": sharingToolsEnabled, "render-caption": show_caption, "render-timephrase": show_timestamp }),
                            tagsEnabled && (createElement("tile-tags", { widgetId: sdk.getWidgetId(), "tile-id": tile.id, mode: "swiper", context: "expanded", "navigation-arrows": "true" })),
                            productsEnabled && (createElement(createFragment, null,
                                createElement("ugc-products", { widgetId: sdk.getWidgetId(), "tile-id": tile.id }))))))))));
}
export function IconSection({ tile, productsEnabled }) {
    const topSectionIconContent = [];
    const bottomSectionIconContent = [];
    if (tile.attrs?.includes("instagram.reel")) {
        topSectionIconContent.push(createElement("div", { class: "content-icon icon-reel" }));
    }
    else if (tile.attrs?.includes("youtube.short")) {
        topSectionIconContent.push(createElement("div", { class: "content-icon icon-youtube-short" }));
    }
    if (productsEnabled &&
        tile.tags_extended &&
        tile.tags_extended.length &&
        tile.tags_extended.find(tag => tag.type == "product")) {
        topSectionIconContent.push(createElement("div", { class: "shopping-icon icon-products" }));
    }
    bottomSectionIconContent.push(createElement("div", { class: `network-icon icon-${tile.source}` }));
    return (createElement("div", { class: "icon-section" },
        createElement("div", { class: "top-section" }, ...topSectionIconContent),
        createElement("div", { class: "bottom-section" }, ...bottomSectionIconContent)));
}
export function ShopSpotTemplate({ shopspotEnabled, tileId, sdk }) {
    return shopspotEnabled ? (createElement(createFragment, null,
        createElement("shopspot-icon", { widgetId: sdk.getWidgetId(), mode: "expanded", "tile-id": tileId }))) : (createElement(createFragment, null));
}
export function ImageTemplate({ tile, image, shopspotEnabled = false, sdk }) {
    return image ? (createElement(createFragment, null,
        createElement("a", { href: tile.original_url, target: "_blank" },
            createElement("div", { class: "image-filler blurred", style: { "background-image": `url('${image}')` } })),
        createElement("div", { class: "image" },
            shopspotEnabled ? createElement(ShopSpotTemplate, { sdk: sdk, shopspotEnabled: shopspotEnabled, tileId: tile.id }) : createElement(createFragment, null),
            createElement("a", { href: tile.original_url, target: "_blank" },
                createElement("img", { class: "image-element", src: image, loading: "lazy", alt: tile.description || "Image" }))))) : (createElement(createFragment, null));
}
//# sourceMappingURL=tile.template.js.map