var __getOwnPropNames = Object.getOwnPropertyNames;
var __esm = (fn, res) => function __init() {
  return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
};

// src/libs/jsx-html.ts
function createElement(type, props, ...children) {
  if (typeof type === "function") {
    return children?.length ? type({ ...props, children }) : type(props);
  }
  const element = document.createElement(type);
  applyProperties(element, props ?? {});
  children?.forEach((child) => appendChild(element, child));
  return element;
}
function sanitizeHtmlBasic(input) {
  const tempDiv = document.createElement("div");
  tempDiv.innerHTML = input;
  const scripts = tempDiv.querySelectorAll("script, style");
  scripts.forEach((el) => el.remove());
  const allElements = tempDiv.querySelectorAll("*");
  for (const el of allElements) {
    for (const attr of Array.from(el.attributes)) {
      const name = attr.name.toLowerCase();
      if (name.startsWith("on") || name === "srcdoc" || name === "href" && attr.value.startsWith("javascript:")) {
        el.removeAttribute(attr.name);
      }
    }
  }
  return tempDiv.innerHTML;
}
function isEventListener(key, value) {
  return key.startsWith("on") && typeof value === "function";
}
function applyProperties(element, props) {
  Object.entries(props).forEach(([key, value]) => {
    if (isEventListener(key, value)) {
      element.addEventListener(key.slice(2).toLowerCase(), value);
    } else if (key === "style") {
      Object.assign(element.style, value);
    } else if (key === "dangerouslySetInnerHTML") {
      const htmlValue = value;
      const sanitizedValue = sanitizeHtmlBasic(htmlValue.__html);
      element.innerHTML = sanitizedValue;
    } else {
      const normKey = aliases[key] ?? key;
      element.setAttribute(normKey, String(value));
    }
  });
}
function appendChild(element, child) {
  if (Array.isArray(child)) {
    child.forEach((c) => appendChild(element, c));
  } else if (child instanceof DocumentFragment) {
    Array.from(child.children).forEach((c) => element.appendChild(c));
  } else if (child instanceof HTMLElement) {
    element.appendChild(child);
  } else if (child !== void 0 && child !== null && child !== false) {
    element.appendChild(document.createTextNode(String(child)));
  }
}
var aliases;
var init_jsx_html = __esm({
  "src/libs/jsx-html.ts"() {
    "use strict";
    aliases = {
      className: "class",
      htmlFor: "for"
    };
  }
});

// src/libs/css-variables.ts
var init_css_variables = __esm({
  "src/libs/css-variables.ts"() {
    "use strict";
  }
});

// src/events/index.ts
var EVENT_TILES_DEPLETED;
var init_events = __esm({
  "src/events/index.ts"() {
    "use strict";
    EVENT_TILES_DEPLETED = "tilesDepleted";
  }
});

// src/libs/widget.features.ts
var init_widget_features = __esm({
  "src/libs/widget.features.ts"() {
    "use strict";
  }
});

// src/libs/loader.extension.ts
var init_loader_extension = __esm({
  "src/libs/loader.extension.ts"() {
    "use strict";
  }
});

// src/libs/index.ts
var init_libs = __esm({
  "src/libs/index.ts"() {
    "use strict";
    init_jsx_html();
    init_css_variables();
    init_widget_features();
    init_loader_extension();
  }
});

// src/libs/components/load-more/load-more.template.tsx
function LoadMoreTemplate() {
  return /* @__PURE__ */ createElement("div", { id: "buttons" }, /* @__PURE__ */ createElement("a", { id: "load-more" }, "LOAD MORE"));
}
var init_load_more_template = __esm({
  "src/libs/components/load-more/load-more.template.tsx"() {
    "use strict";
    init_libs();
  }
});

// src/libs/components/load-more/load-more.component.ts
var LoadMoreComponent;
var init_load_more_component = __esm({
  "src/libs/components/load-more/load-more.component.ts"() {
    "use strict";
    init_load_more_template();
    init_events();
    LoadMoreComponent = class extends HTMLElement {
      constructor() {
        super();
      }
      connectedCallback() {
        if (sdk.getStyleConfig().load_more_type === "button") {
          this.appendChild(LoadMoreTemplate());
          sdk.addEventListener(EVENT_TILES_DEPLETED, () => {
            this.replaceChildren();
          });
        }
      }
      disconnectedCallback() {
        this.replaceChildren();
      }
    };
    try {
      customElements.define("load-more", LoadMoreComponent);
    } catch (err) {
    }
  }
});

// src/libs/components/load-more/index.ts
var load_more_default;
var init_load_more = __esm({
  "src/libs/components/load-more/index.ts"() {
    init_load_more_component();
    load_more_default = LoadMoreComponent;
  }
});
init_load_more();
export {
  load_more_default as default
};
