import { EVENT_TILE_EXPAND_RENDERED, EVENT_TILES_UPDATED, EVENT_EXPANDED_TILE_CLOSE, registerDefaultClickEvents, registerGenericEventListener, registerShareMenuClosedListener, registerShareMenuOpenedListener, registerTileExpandListener, registerProductsUpdatedListener, EVENT_TILES_DEPLETED } from "../";
import { loadExpandSettingComponents } from "./widget.components";
import { useInfiniteScroller } from "../hooks";
import { onTileClosed, onTileExpand, onTileRendered, reduceBackgroundControlsVisibility, resetBackgroundControlsVisibility } from "./components/expanded-tile-swiper/expanded-swiper.loader";
import { loadProductsSwiper } from "./components/expanded-tile-swiper/products.swiper";
export const getNextNavigatedTile = (currentTile, enabledTiles, direction) => {
    const currentIndex = enabledTiles.findIndex((tile) => tile.getAttribute("data-id") === currentTile.id);
    if (direction === "previous") {
        const previousTile = getPreviousTile(enabledTiles, currentIndex);
        if (!previousTile) {
            throw new Error("Failed to find previous tile");
        }
        return previousTile.getAttribute("data-id");
    }
    else if (direction === "next") {
        const nextTile = getNextTile(enabledTiles, currentIndex);
        if (!nextTile) {
            throw new Error("Failed to find next tile");
        }
        return nextTile.getAttribute("data-id");
    }
    return null;
};
export const getNextTile = (enabledTiles, currentIndex) => enabledTiles[currentIndex + 1];
export const getPreviousTile = (enabledTiles, currentIndex) => enabledTiles[currentIndex - 1];
export function loadExpandedTileFeature(sdk) {
    const widgetContainer = sdk.getStyleConfig();
    const { click_through_url } = widgetContainer;
    if (click_through_url === "[EXPAND]") {
        loadExpandSettingComponents(sdk);
        registerTileExpandListener(sdk, onTileExpand);
        registerGenericEventListener(sdk, EVENT_EXPANDED_TILE_CLOSE, onTileClosed);
        registerGenericEventListener(sdk, EVENT_TILE_EXPAND_RENDERED, onTileRendered);
        registerShareMenuOpenedListener(sdk, (sourceId) => reduceBackgroundControlsVisibility(sdk, sourceId));
        registerShareMenuClosedListener(sdk, (sourceId) => resetBackgroundControlsVisibility(sdk, sourceId));
        registerProductsUpdatedListener(sdk, loadProductsSwiper);
    }
    else if (click_through_url === "[ORIGINAL_URL]" || /^https?:\/\/.+/.test(click_through_url ?? "")) {
        registerDefaultClickEvents(sdk);
    }
    else if (click_through_url === "[CUSTOM]") {
        alert("Custom URL integration Not implemented yet");
    }
}
export function addAutoAddTileFeature(sdk) {
    const { auto_refresh } = sdk.getStyleConfig();
    // FIXME: Make auto_refresh boolean across the board
    if (Boolean(auto_refresh) === true) {
        sdk.enableAutoAddNewTiles();
    }
}
function loadMore(sdk) {
    if (window.__isLoading) {
        return;
    }
    window.__isLoading = true;
    sdk.loadMore();
    setTimeout(() => {
        window.__isLoading = false;
    }, 500);
}
const getLoadMoreButton = (sdk) => {
    const loadMoreComponent = sdk.querySelector("load-more");
    if (!loadMoreComponent) {
        throw new Error("Failed to find load more component");
    }
    const loadMoreButton = loadMoreComponent?.querySelector("#load-more");
    if (!loadMoreButton) {
        throw new Error("Failed to find load more button");
    }
    return loadMoreButton;
};
const loadMoreWrappedWithEasedLoader = (sdk) => {
    const loadMoreButton = getLoadMoreButton(sdk);
    loadMoreButton.classList.add("hidden");
    loadMore(sdk);
};
// TODO, move all to load-more web component
export function addLoadMoreButtonFeature(sdk) {
    const { load_more_type } = sdk.getStyleConfig();
    const loadMoreType = load_more_type;
    switch (loadMoreType) {
        case "button":
            attachLoadMoreButtonListener(sdk);
            sdk.addEventListener(EVENT_TILES_UPDATED, () => {
                const loadMoreButton = getLoadMoreButton(sdk);
                loadMoreButton.classList.remove("hidden");
            });
            sdk.addEventListener(EVENT_TILES_DEPLETED, () => {
                disableLoadMoreButtonIfExists(sdk);
            });
            break;
        case "scroll":
            useInfiniteScroller(sdk, window);
            break;
        case "static":
            disableLoadMoreButtonIfExists(sdk);
            break;
        default:
            throw new Error("Invalid load more type");
    }
}
export function attachLoadMoreButtonListener(sdk) {
    const loadMoreButton = getLoadMoreButton(sdk);
    loadMoreButton.onclick = () => loadMoreWrappedWithEasedLoader(sdk);
}
export function disableLoadMoreButtonIfExists(sdk) {
    const loadMoreButton = getLoadMoreButton(sdk);
    loadMoreButton.classList.add("hidden");
}
export function loadTitle(sdk) {
    const widgetTitle = document.createElement("p");
    const widgetContainer = sdk.getWidgetContainer();
    const title = widgetContainer.title;
    if (title) {
        widgetTitle.innerHTML = title;
    }
}
export function waitForElm(parent, targets, callback) {
    if (targets.every(it => !!parent.querySelector(it))) {
        callback(targets.map(it => parent.querySelector(it)));
    }
    const observer = new MutationObserver((_, observer) => {
        if (targets.every(it => !!parent.querySelector(it))) {
            observer.disconnect();
            callback(targets.map(it => parent.querySelector(it)));
        }
    });
    observer.observe(parent, {
        childList: true,
        subtree: true
    });
}
export function waitForElements(parent, target, callback) {
    const elements = parent.querySelectorAll(target);
    if (elements.length > 0) {
        callback(elements);
    }
    const observer = new MutationObserver(() => {
        const newElements = parent.querySelectorAll(target);
        if (newElements.length > 0) {
            callback(newElements);
            observer.disconnect();
        }
    });
    observer.observe(parent, {
        childList: true,
        subtree: true
    });
}
export function getSdk() {
    if (sdk) {
        return sdk;
    }
    const firstChild = document.querySelector("#ugc-widget")?.firstChild;
    const tagName = firstChild?.tagName;
    const widget = window.ugc.getWidgetBySelector(tagName);
    if (!widget) {
        throw new Error(`Failed to load SDK, widget not found ${tagName}`);
    }
    return widget.sdk;
}
//# sourceMappingURL=widget.features.js.map